@@ -3,10 +3,12 @@ import logging
 import requests
 from FunctionalTests.FunctionalParam import FunctionalParam
 # from jsonpath_ng import jsonpath, parse
-
+from Config.Defaultheader import Defaultheader
 functionalParm = FunctionalParam()
 logger = logging.getLogger()
 logger.setLevel(logging.DEBUG)
+header = Defaultheader()
+
 
 stagelink = "ifi/151613/"
 endpoint = "https://plutus.mum1-stage.zeta.in/plutus-onboarding/send/otp"
